#
# spec file for package lziprecover
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without tests
Name:           lziprecover
Version:        1.25
Release:        2.1
Summary:        Utility to repair broken lzip files
License:        GPL-2.0-or-later
Group:          Productivity/Archiving/Compression
URL:            http://www.nongnu.org/lzip/lunzip.html
Source:         http://download.savannah.gnu.org/releases/lzip/lziprecover/%name-%version.tar.gz
Source2:        http://download.savannah.gnu.org/releases/lzip/lziprecover/%name-%version.tar.gz.sig
Source3:        %name.keyring
BuildRequires:  gcc-c++
%if %{with tests}
BuildRequires:  lzip >= 1.16
%endif
Requires(post): info
Requires(preun):info

%description
Lziprecover is a data recovery tool and decompressor for files in the
lzip compressed data format (.lz) able to repair slightly damaged
files, recover badly damaged files from two or more copies, extract
undamaged members from multi-member files, decompress files and test
integrity of files.

Lziprecover is able to recover or decompress files produced by any of
the compressors in the lzip family; lzip, plzip, minilzip/lzlib,
clzip and pdlzip. This recovery capability contributes to make the
lzip format one of the best options for long-term data archiving.

Lziprecover is able to efficiently extract a range of bytes from a
multi-member file, because it only decompresses the members
containing the desired data.

Lziprecover can print correct total file sizes and ratios even for
multi-member files.

%prep
%autosetup -p1

%build
# not autoconf
mkdir build
pushd build/
../configure --prefix="%_prefix" --bindir="%_bindir" --datadir="%_datadir" \
	--infodir="%_infodir" --mandir="%_mandir" --sysconfdir="%_sysconfdir" \
	CXXFLAGS="%optflags"
%make_build
popd

%install
pushd build/
%make_install
popd

%if %{with tests}
%check
pushd build/
%make_build check
popd
%endif

%post
%install_info --info-dir="%_infodir" "%_infodir/%name".info*

%postun
%install_info_delete --info-dir="%_infodir" "%_infodir/%name".info*

%files
%doc ChangeLog README
%license COPYING
%_bindir/lziprecover
%_mandir/man1/lziprecover.1*
%_infodir/lziprecover.info*

%changelog
* Mon Jan 20 2025 Andreas Schwab <schwab@suse.de>
- Build with %%optflags
* Sun Jan 19 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.25
  * Added new options: -F/--fec, -0 .. -9, -b/--block-size,
  - -fec-file, -r/--recursive, -R/--dereference-recursive.
  * The short name of option `--byte-repair` has been changed to
    `-B`.
  * The option `--byte-repair` now repairs a nonzero first LZMA
    byte.
  * When decompressing, testing, or listing, lziprecover now exits
    with error status 2 if any empty member is found in a regular
    multimember file unless `-i` is given.
  * When decompressing or testing, lziprecover now exits with error
    status 2 if the first byte of the LZMA stream is not 0 unless
    `-i` is given.
  * The option `--clear-marking` has been renamed to
    `--nonzero-repair`.
  * Options `--empty-error` and `--marking-error` have been removed.
* Thu Feb  8 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.24
  * Added the command-line switches --empty-error,
  - -marking-error and --clear-marking
  * Options were renamed: --repair to --byte-repair, --debug-repair
    to --debug-byte-repair, --no-verify to --no-check.
  * The option -o/--output now preserves dates, permissions, and
    ownership of the file when (de)compressing exactly one file.
  * The option -o/--output now creates missing intermediate
    directories when writing to a file.
* Sun Feb 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.23
  * Decompression time has been reduced by 5-12%% depending on the
    file.
  * In case of error in a numerical argument to a command line
    option, lziprecover now shows the name of the option and the
    range of valid values.
  * Options "--dump" and "--strip" now refuse to write compressed
    data to a terminal except when dumping trailing data with
    "--dump=tdata".
  * The option "-U, --unzcrash" now requires an argument: "1"
    to test 1-bit errors, or "B<size>" to test zeroed blocks.
  * The memory tester now allocates the dictionary once per
    member instead of doing it for each test. This makes "-U,
  - -unzcrash" about two times faster on my machine on files
    with an uncompressed size larger than about 30 MB.
  * "-W, --debug-decompress" now continues decompressing the
    members following the damaged member if it has been fully
    decompressed (just failed with a CRC mismatch).
  * The tool unzcrash now prints byte or block position in messages.
* Fri Mar 12 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.22
  * New options: -e/--reproduce, --lzip-level, --lzip-name,
  - -reference-file and -E/--debug-reproduce.
  * Remove --dump-tdata, --remove-tdata and --strip-tdata.
  * New debug options -M/--md5sum and -U/--unzcrash.
* Mon Jan  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.21
  * No differential changelog to 1.21~rc1 provided.
* Fri Dec 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.21~rc1
  * The options '--dump', '--remove' and '--strip' have been
    added, mainly as support for the tarlz archive format.
  * Detection of forbidden combinations of characters in trailing
    data has been improved.
  * '--split' can now detect trailing data and gaps between
    members, and save each gap in its own file. Trailing data (if
    any) are saved alone in the last file. (Gaps may contain
    garbage or may be members with corrupt headers or trailers).
  * '--ignore-errors' now makes '--list' show gaps between
    members, ignoring format errors.
  * '--ignore-errors' now makes '--range-decompress' ignore a
    truncated last member.
  * '--ignore-errors' now makes '--dump', '--remove' and
    '--strip' ignore format errors.
* Mon Mar  5 2018 jengelh@inai.de
- Update to new upstream release 1.20
  * Splitting was broken for files larger than 64 KiB because of
    a bug introduced in version 1.16.
  * The options "--dump-tdata", "--remove-tdata", and
    "--strip-tdata" have been added to ease the management of
    metadata stored as trailing data.
  * The option "--loose-trailing", has been added.
  * The test used by lziprecover to discriminate trailing data
    from a corrupt header in multimember or concatenated files
    has been improved to a Hamming distance of 3.
* Wed Jul  5 2017 jengelh@inai.de
- Update to new upstream release 1.19 (2017-04-17)
  * '--merge' is now able to fix files with thousands of scattered
    errors per member by grouping the errors into clusters and then
    merging the files as if each cluster were a single error.
  * The option '-a, --trailing-error' now also works with
    '-l, --list' and '-D, --range-decompress'.
* Mon Nov 21 2016 jengelh@inai.de
- Update to new upstream release 1.18
  * The option "-a, --trailing-error", which makes lziprecover exit
    with error status 2 if any remaining input is detected after
    decompressing the last member, has been added.
  * "--merge" now detects identical files by their CRC.
  * "--repair" now tries to detect gross damage in the file before
    attempting to repair it.
  * "--repair" now can repair a damaged dictionary size in the header.
  * When decompressing, the file specified with the "--output"
    option is now deleted if the input is a terminal.
  * "--merge", "--range-decompress", "--repair" and "--split" now
    preserve dates, permissions, and, when possible, ownership of
    the files created just as "--decompress" does.
  * The new option "-A, --alone-to-lz", which converts lzma-alone
    files to lzip format without recompressing, just adding a lzip
    header and trailer, has been added. Only streamed files with
    default LZMA properties can be converted; non-streamed
    lzma-alone files lack the end of stream marker required in lzip
    files.
  * The new option "-W, --debug-decompress=<pos>,<val>", which sets
    the byte <pos> to the value <val> and then decompresses to
    stdout the resulting corrupt data, has been added.
  * The new option "-X, --show-packets", which shows the LZMA
    packets (coding sequences) coded in a given file, has been
    added.
  * The new options "-B, --block", "-d, --delta", "-t, --truncate"
    and "-z, --zcmp" have been added to unzcrash.
* Sat Nov  7 2015 jengelh@inai.de
- Update to new upstream release 1.17
  * Merging files now uses an algorithm similar to the ones used to
  solve the "Master Mind" game, which makes it much faster. Up to
  two orders of magnitude faster depending on number of files and
  number of errors.
  * Repair time has been reduced by 15%%.
* Wed Oct  1 2014 jengelh@inai.de
- Update to new upstream release 1.16
  * Repairing of single-byte errors is now about 10 times faster,
  depending on file size and position of error.
  * Copying of file dates, permissions, and ownership now behaves
  like `cp -p`. (If the user ID or the group ID cannot be
  duplicated, the file permission bits S_ISUID and S_ISGID are
  cleared).
  * The license has been changed to GPL version 2 or later.
* Sun Sep 29 2013 jengelh@inai.de
- Update to new upstream release 1.15
  * Lziprecover can now repair multi-member files with up to one byte
  error per member, without having to split them first.
  * Lziprecover can now merge multi-member files without having to
  split them first, even if some copies have the header and the
  trailer damaged.
* Mon Jun 10 2013 jengelh@inai.de
- Update to new upstream release 1.14
  * The new option "-i, --ignore-errors", which in conjunction with
  "-D" decompresses all the recoverable data in all members of a
  file without having to split it first, has been added.
  * Option "-l, --list" now accepts more than one file.
  * Decompression time has been reduced by 12%%.
  * "--split" now uses as few digits as possible in the names of the
  files produced, depending on the number of members in the input
  file.
  * "--split" in verbose mode now shows the names of files being
  created.
- Wrap description at 70 cols; more robust make install call;
  remove redundant %%clean section; signature verification
* Tue Apr  3 2012 pascal.bleser@opensuse.org
- initial version (1.13)
